@@ -25,7 +25,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "../search/trace_pt_buffer.h"
 #include "../util/task_queue.h"
 #include "../basic/statistics.h"
-#include "query_mapper.h"
+#include "legacy/query_mapper.h"
 #include "../data/metadata.h"
 
 using std::vector;
@@ -71,8 +71,8 @@ namespace ExtensionPipeline {
 		struct Target;
 		struct Pipeline : public QueryMapper
 		{
-			Pipeline(const Parameters &params, size_t query_id, Trace_pt_list::iterator begin, Trace_pt_list::iterator end) :
-				QueryMapper(params, query_id, begin, end)
+			Pipeline(const Parameters &params, size_t query_id, Trace_pt_list::iterator begin, Trace_pt_list::iterator end, const Metadata &metadata) :
+				QueryMapper(params, query_id, begin, end, metadata)
 			{}
 			Target& target(size_t i);
 			virtual void run(Statistics &stat, const sequence *subjects = nullptr, size_t subject_count = 0);
@@ -82,8 +82,8 @@ namespace ExtensionPipeline {
 	namespace Swipe {
 		struct Pipeline : public QueryMapper
 		{
-			Pipeline(const Parameters &params, size_t query_id, Trace_pt_list::iterator begin, Trace_pt_list::iterator end) :
-				QueryMapper(params, query_id, begin, end)
+			Pipeline(const Parameters &params, size_t query_id, Trace_pt_list::iterator begin, Trace_pt_list::iterator end, const Metadata &metadata) :
+				QueryMapper(params, query_id, begin, end, metadata)
 			{}
 			virtual void run(Statistics &stat, const sequence *subjects = nullptr, size_t subject_count = 0);
 			virtual ~Pipeline() {}
@@ -93,8 +93,8 @@ namespace ExtensionPipeline {
 		struct Target;
 		struct Pipeline : public QueryMapper
 		{
-			Pipeline(const Parameters &params, size_t query_id, Trace_pt_list::iterator begin, Trace_pt_list::iterator end, DpStat &dp_stat, bool target_parallel) :
-				QueryMapper(params, query_id, begin, end, target_parallel),
+			Pipeline(const Parameters &params, size_t query_id, Trace_pt_list::iterator begin, Trace_pt_list::iterator end, DpStat &dp_stat, const Metadata &metadata, bool target_parallel) :
+				QueryMapper(params, query_id, begin, end, metadata, target_parallel),
 				dp_stat(dp_stat)
 			{}
 			Target& target(size_t i);
