@@ -1,6 +1,6 @@
 /****
 DIAMOND protein aligner
-Copyright (C) 2013-2017 Benjamin Buchfink <buchfink@gmail.com>
+Copyright (C) 2013-2019 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -74,7 +74,13 @@ Config::Config(int argc, const char **argv)
 		.add_command("filter-blasttab", "")
 		.add_command("show-cbs", "")
 		.add_command("simulate-seqs", "")
-		.add_command("split", "");
+		.add_command("split", "")
+		.add_command("upgma", "")
+		.add_command("upgmamc", "")
+		.add_command("test", "")
+		.add_command("reverse", "")
+		.add_command("compute-medoids", "")
+		.add_command("mutate", "");
 
 	Options_group general("General options");
 	general.add()
@@ -114,7 +120,12 @@ Config::Config(int argc, const char **argv)
 \tppos means Percentage of positive - scoring matches\n\
 \tqframe means Query frame\n\
 \tbtop means Blast traceback operations(BTOP)\n\
+\tcigar means CIGAR string\n\
 \tstaxids means unique Subject Taxonomy ID(s), separated by a ';' (in numerical order)\n\
+\tsscinames means unique Subject Scientific Name(s), separated by a ';'\n\
+\tsskingdoms means unique Subject Super Kingdom(s), separated by a ';'\n\
+\tskingdoms means unique Subject Kingdom(s), separated by a ';'\n\
+\tsphylums means unique Subject Phylum(s), separated by a ';'\n\
 \tstitle means Subject Title\n\
 \tsalltitles means All Subject Title(s), separated by a '<>'\n\
 \tqcovhsp means Query Coverage Per HSP\n\
@@ -196,14 +207,13 @@ Config::Config(int argc, const char **argv)
 		("rank-ratio", 0, "include subjects within this ratio of last hit (stage 1)", rank_ratio, -1.0)
 		("rank-ratio2", 0, "include subjects within this ratio of last hit (stage 2)", rank_ratio2, -1.0)
 		("max-hsps", 0, "maximum number of HSPs per subject sequence to save for each query", max_hsps, 0u)
+		("taxon-k", 0, "maximum number of targets to report per species", taxon_k, (uint64_t)0)
 		("range-cover", 0, "percentage of query range to be covered for hit culling (default=50)", query_range_cover, 50.0)
 		("dbsize", 0, "effective database size (in letters)", db_size)
 		("no-auto-append", 0, "disable auto appending of DAA and DMND file extensions", no_auto_append)
 		("xml-blord-format", 0, "Use gnl|BL_ORD_ID| style format in XML output", xml_blord_format)
 		("stop-match-score", 0, "Set the match score of stop codons against each other.", stop_match_score, 1)
-		("tantan-minMaskProb", 0, "minimum repeat probability for masking (0.9)", tantan_minMaskProb, 0.9)
-		("tantan-maxRepeatOffset", 0, "maximum tandem repeat period to consider (50)", tantan_maxRepeatOffset, 15)
-		("tantan-ungapped", 0, "use tantan masking in ungapped mode", tantan_ungapped);
+		("tantan-minMaskProb", 0, "minimum repeat probability for masking (0.9)", tantan_minMaskProb, 0.9);
 
 	Options_group view_options("View options");
 	view_options.add()
@@ -281,8 +291,17 @@ Config::Config(int argc, const char **argv)
 		("cbs-window", 0, "", cbs_window, 40)
 		("no-unlink", 0, "", no_unlink)
 		("no-dict", 0, "", no_dict)
-		("swipe", 0, "", swipe_all);
-		
+		("swipe", 0, "", swipe_all)
+		("upgma-edge-limit", 0, "", upgma_edge_limit, (uint64_t)10000000)
+		("tree", 0, "", tree_file)
+		("upgma-dist", 0, "", upgma_dist)
+		("upgma-input", 0, "", upgma_input)
+		("log-extend", 0, "", log_extend)
+		("chaining-maxgap", 0, "", chaining_maxgap, 2000)
+		("tantan-maxRepeatOffset", 0, "maximum tandem repeat period to consider (50)", tantan_maxRepeatOffset, 15)
+		("tantan-ungapped", 0, "use tantan masking in ungapped mode", tantan_ungapped)
+		("family-map", 0, "", family_map);
+	
 	parser.add(general).add(makedb).add(aligner).add(advanced).add(view_options).add(getseq_options).add(hidden_options);
 	parser.store(argc, argv, command);
 
@@ -377,9 +396,8 @@ Config::Config(int argc, const char **argv)
 	}
 
 	ostream &header_out = command == Config::help ? cout : cerr;
-	header_out << Const::program_name << " v" << Const::version_string << "." << (unsigned)Const::build_version << " | by Benjamin Buchfink <buchfink@gmail.com>" << endl;
-	header_out << "Licensed under the GNU GPL <https://www.gnu.org/licenses/gpl.txt>" << endl;
-	header_out << "Check http://github.com/bbuchfink/diamond for updates." << endl << endl;
+	header_out << Const::program_name << " v" << Const::version_string << "." << (unsigned)Const::build_version << " (C) Max Planck Society for the Advancement of Science" << endl;
+	header_out << "Documentation, support and updates available at http://www.diamondsearch.org" << endl << endl;
 	log_stream << Const::program_name << " v" << Const::version_string << "." << (unsigned)Const::build_version << endl;
 #ifndef NDEBUG
 	verbose_stream << "Assertions enabled." << endl;
@@ -392,6 +410,7 @@ Config::Config(int argc, const char **argv)
 	case Config::blastx:
 	case Config::view:
 	case Config::cluster:
+	case Config::compute_medoids:
 		message_stream << "#CPU threads: " << threads_ << endl;
 	default:
 		;
@@ -406,6 +425,7 @@ Config::Config(int argc, const char **argv)
 	case Config::mask:
 	case Config::makedb:
 	case Config::cluster:
+	case Config::compute_medoids:
 		if (frame_shift != 0 && command == Config::blastp)
 			throw std::runtime_error("Frameshift alignments are only supported for translated searches.");
 		if (query_range_culling && frame_shift == 0)
@@ -425,7 +445,7 @@ Config::Config(int argc, const char **argv)
 	}
 
 	if (command == Config::blastp || command == Config::blastx || command == Config::benchmark || command == Config::model_sim || command == Config::opt
-		|| command == Config::mask || command == Config::cluster) {
+		|| command == Config::mask || command == Config::cluster || command == Config::compute_medoids) {
 		if (tmpdir == "")
 			tmpdir = extract_dir(output_file);
 		
@@ -459,4 +479,7 @@ Config::Config(int argc, const char **argv)
 	}
 
 	use_lazy_dict = false;
+
+	if (query_range_culling && taxon_k != 0)
+		throw std::runtime_error("--taxon-k is not supported for --range-culling mode.");
 }
