@@ -18,9 +18,10 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <math.h>
 #include <algorithm>
+#include <atomic>
 #include "masking.h"
-#include "../lib/tantan/tantan.hh"
 #include "../lib/tantan/LambdaCalculator.hh"
+#include "../util/tantan.h"
 
 using namespace std;
 
@@ -43,34 +44,21 @@ Masking::Masking(const Score_matrix &score_matrix)
 		mask_table_x_[i] = value_traits.mask_char;
 		mask_table_bit_[i] = (uint8_t)i | bit_mask;
 		for (unsigned j = 0; j < size; ++j)
-			if (i < n && j < n)
-				likelihoodRatioMatrix_[i][j] = exp(lambda * score_matrix(i, j));
+			if (i < n && j < n) {
+				likelihoodRatioMatrixf_[i][j] = (float)exp(lambda * score_matrix(i, j));
+			}
 	}
-	std::copy(likelihoodRatioMatrix_, likelihoodRatioMatrix_ + size, probMatrixPointers_);
-	int firstGapCost = score_matrix.gap_extend() + score_matrix.gap_open();
-	firstGapProb_ = exp(-lambda * firstGapCost);
-	otherGapProb_ = exp(-lambda * score_matrix.gap_extend());
-	firstGapProb_ /= (1 - otherGapProb_);
+	std::copy(likelihoodRatioMatrixf_, likelihoodRatioMatrixf_ + size, probMatrixPointersf_);
 }
 
 void Masking::operator()(Letter *seq, size_t len) const
 {
-	tantan::maskSequences((tantan::uchar*)seq, (tantan::uchar*)(seq + len), config.tantan_maxRepeatOffset,
-		(tantan::const_double_ptr*)probMatrixPointers_,
-		0.005, 0.05,
-		0.9,
-		config.tantan_ungapped ? 0.0 : firstGapProb_, config.tantan_ungapped ? 0.0 : otherGapProb_,
-		config.tantan_minMaskProb, (const tantan::uchar*)mask_table_x_);
+	Util::tantan::mask(seq, len, (const float**)probMatrixPointersf_, 0.005f, 0.05f, 1.0f / 0.9f, config.tantan_minMaskProb, mask_table_x_);
 }
 
 void Masking::mask_bit(Letter *seq, size_t len) const
 {
-	tantan::maskSequences((tantan::uchar*)seq, (tantan::uchar*)(seq + len), config.tantan_maxRepeatOffset,
-		(tantan::const_double_ptr*)probMatrixPointers_,
-		0.005, 0.05,
-		0.9,
-		config.tantan_ungapped ? 0.0 : firstGapProb_, config.tantan_ungapped ? 0.0 : otherGapProb_,
-		config.tantan_minMaskProb, (const tantan::uchar*)mask_table_bit_);
+	Util::tantan::mask(seq, len, (const float**)probMatrixPointersf_, 0.005f, 0.05f, 1.0f / 0.9f, config.tantan_minMaskProb, mask_table_bit_);
 }
 
 void Masking::bit_to_hard_mask(Letter *seq, size_t len, size_t &n) const
@@ -89,7 +77,7 @@ void Masking::remove_bit_mask(Letter *seq, size_t len) const
 			seq[i] &= ~bit_mask;
 }
 
-void mask_worker(Atomic<size_t> *next, Sequence_set *seqs, const Masking *masking, bool hard_mask)
+void mask_worker(atomic<size_t> *next, Sequence_set *seqs, const Masking *masking, bool hard_mask)
 {
 	size_t i;
 	while ((i = (*next)++) < seqs->get_length())
@@ -102,7 +90,7 @@ void mask_worker(Atomic<size_t> *next, Sequence_set *seqs, const Masking *maskin
 size_t mask_seqs(Sequence_set &seqs, const Masking &masking, bool hard_mask)
 {
 	vector<thread> threads;
-	Atomic<size_t> next(0);
+	atomic<size_t> next(0);
 	for (size_t i = 0; i < config.threads_; ++i)
 		threads.emplace_back(mask_worker, &next, &seqs, &masking, hard_mask);
 	for (auto &t : threads)
