@@ -3,16 +3,16 @@ DIAMOND protein aligner
 Copyright (C) 2013-2017 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU Affero General Public License as
-published by the Free Software Foundation, either version 3 of the
-License, or (at your option) any later version.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU Affero General Public License for more details.
+GNU General Public License for more details.
 
-You should have received a copy of the GNU Affero General Public License
+You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
@@ -41,7 +41,8 @@ struct Reduction
 		map_[(long)Translator::STOP] = value_traits.mask_char;
 		const vector<string> tokens(tokenize(definition_string, " "));
 		size_ = (unsigned)tokens.size();
-		bit_size_ = (uint64_t)ceil(log(size_) / log(2));
+		bit_size_exact_ = log(size_) / log(2);
+		bit_size_ = (uint64_t)ceil(bit_size_exact_);
 		for (unsigned i = 0; i<size_; ++i)
 			for (unsigned j = 0; j<tokens[i].length(); ++j) {
 				const char ch = tokens[i][j];
@@ -61,6 +62,10 @@ struct Reduction
 		return bit_size_;
 	}
 
+	double bit_size_exact() const {
+		return bit_size_exact_;
+	}
+
 	unsigned operator()(Letter a) const
 	{
 		return map_[(long)a];
@@ -108,6 +113,7 @@ private:
 #endif
 	unsigned size_;
 	uint64_t bit_size_;
+	double bit_size_exact_;
 
 };
 
