@@ -36,7 +36,7 @@ typedef double array_of_8[BLAST_NUM_STAT_VALUES];
 
 const double INT2_MAX = std::numeric_limits<double>::max();
 
-const char DNA_scores[5 * 5] = {
+const signed char DNA_scores[5 * 5] = {
 	2, -3, -3, -3, -3,
 	-3,2,-3,-3,-3,
 	-3,-3,2,-3,-3,
@@ -317,4 +317,4 @@ Score_matrix::Score_matrix(const string &matrix_file, double lambda, double K, i
 	constants[3] = lambda;
 	constants[4] = K;
 	constants_ = constants;
-}
\ No newline at end of file
+}
