@@ -21,6 +21,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <iostream>
 #include <vector>
+#include <string>
 #include "../basic/value.h"
 #include "../util/binary_buffer.h"
 #include "../util/text_buffer.h"
@@ -32,6 +33,7 @@ struct sequence
 {
 	static const char DELIMITER = '\x1f';
 	struct Reversed {};
+	struct Hardmasked {};
 	sequence():
 		len_ (0),
 		clipping_offset_ (0),
@@ -125,6 +127,17 @@ struct sequence
 		}
 		return os;
 	}
+	TextBuffer& print(TextBuffer &os, const Value_traits &v, Hardmasked) const
+	{
+		for (unsigned i = 0; i < len_; ++i) {
+			long l = (long)data_[i];
+			if ((l & 128) == 0)
+				os << v.alphabet[l];
+			else
+				os << v.alphabet[(long)v.mask_char];
+		}
+		return os;
+	}
 	TextBuffer& print(TextBuffer &os, const Value_traits &v, Reversed) const
 	{
 		for (int i = (int)len_ - 1; i >= 0; --i)
@@ -135,6 +148,9 @@ struct sequence
 	{
 		return sequence(*this, begin, end - 1);
 	}
+	std::string substr(int begin, int end) const {
+		return std::string(&data_[begin], &data_[end]);
+	}
 	friend TextBuffer& operator<<(TextBuffer &buf, const sequence &s)
 	{
 		return s.print(buf, value_traits);
