@@ -3,16 +3,16 @@ DIAMOND protein aligner
 Copyright (C) 2013-2017 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU Affero General Public License as
-published by the Free Software Foundation, either version 3 of the
-License, or (at your option) any later version.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU Affero General Public License for more details.
+GNU General Public License for more details.
 
-You should have received a copy of the GNU Affero General Public License
+You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
@@ -20,6 +20,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #define INDEX_H_
 
 #include <vector>
+#include <memory>
 #include "sequence_set.h"
 #include "../util/hash_table.h"
 #include "seed_histogram.h"
@@ -60,7 +61,7 @@ private:
 	static void fill_tables(Atomic<unsigned> *seedp, Seed_index *idx);
 	static void count_seeds(Atomic<unsigned> *seedp, vector<size_t> *counts, sorted_list *list);
 
-	auto_ptr<char> list_buffer;
+	std::unique_ptr<char> list_buffer;
 	sorted_list list;
 	PHash_table<Entry> tables[Const::seedp];
 
