@@ -21,25 +21,14 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 // #define DP_STAT
 
+#include <stdint.h>
 #include "../dp.h"
 
 template<int _n>
 struct TargetIterator
 {
 
-	TargetIterator(vector<DpTarget>::const_iterator subject_begin, vector<DpTarget>::const_iterator subject_end) :
-		next(0),
-		n_targets(int(subject_end - subject_begin)),
-		subject_begin(subject_begin)
-	{
-		for (; next < std::min(_n, n_targets); ++next) {
-			pos[next] = 0;
-			target[next] = next;
-			active.push_back(next);
-		}
-	}
-
-	TargetIterator(vector<DpTarget>::const_iterator subject_begin, vector<DpTarget>::const_iterator subject_end, int i1, int qlen) :
+	TargetIterator(vector<DpTarget>::const_iterator subject_begin, vector<DpTarget>::const_iterator subject_end, int i1, int qlen, int *d_begin) :
 		next(0),
 		n_targets(int(subject_end - subject_begin)),
 		cols(0),
@@ -48,7 +37,7 @@ struct TargetIterator
 		for (; next < std::min(_n, n_targets); ++next) {
 			const DpTarget &t = subject_begin[next];
 			pos[next] = i1 - (t.d_end - 1);
-			const int j1 = std::min(qlen - 1 - t.d_begin, (int)(t.seq.length() - 1)) + 1;
+			const int j1 = std::min(qlen - 1 - d_begin[next], (int)(t.seq.length() - 1)) + 1;
 			cols = std::max(cols, j1 - pos[next]);
 			target[next] = next;
 			active.push_back(next);
@@ -118,4 +107,89 @@ struct TargetIterator
 	const vector<DpTarget>::const_iterator subject_begin;
 };
 
+template<int _n>
+struct TargetBuffer
+{
+
+	TargetBuffer(const sequence *subject_begin, const sequence *subject_end) :
+		next(0),
+		n_targets(int(subject_end - subject_begin)),
+		subject_begin(subject_begin)
+	{
+		for (; next < std::min(_n, n_targets); ++next) {
+			pos[next] = 0;
+			target[next] = next;
+			active.push_back(next);
+		}
+	}
+
+#ifdef DP_STAT
+	char operator[](int channel)
+#else
+	char operator[](int channel) const
+#endif
+	{
+		if (pos[channel] >= 0) {
+#ifdef DP_STAT
+			++live;
+#endif
+			return subject_begin[target[channel]][pos[channel]];
+		}
+		else
+			return value_traits.mask_char;
+	}
+
+#ifdef __SSSE3__
+#ifdef DP_STAT
+	template<typename _t> __m128i seq_vector(const _t&)
+#else
+	template<typename _t> __m128i seq_vector(const _t&) const
+#endif	
+	{
+		_t s[_n];
+		for (int i = 0; i < active.size(); ++i) {
+			const int channel = active[i];
+			s[channel] = (*this)[channel];
+		}
+		return _mm_loadu_si128((const __m128i*)s);
+	}
+#else
+	template<typename _t> uint64_t seq_vector(const _t&)
+	{
+		uint64_t dst = 0;
+		for (int i = 0; i < active.size(); ++i) {
+			const int channel = active[i];
+			dst |= uint64_t((*this)[channel]) << (8 * channel);
+		}
+		return dst;
+	}
+#endif
+
+	bool init_target(int i, int channel)
+	{
+		if (next < n_targets) {
+			pos[channel] = 0;
+			target[channel] = next++;
+			return true;
+		}
+		active.erase(i);
+		return false;
+	}
+
+	bool inc(int channel)
+	{
+		++pos[channel];
+		if (pos[channel] >= (int)subject_begin[target[channel]].length())
+			return false;
+		return true;
+	}
+
+	int pos[_n], target[_n], next, n_targets, cols;
+#ifdef DP_STAT
+	int live;
+#endif
+	Static_vector<int, _n> active;
+	const sequence *subject_begin;
+};
+
 #endif
\ No newline at end of file
