@@ -84,7 +84,10 @@ const char* Blast_tab_format::field_str[] = {
 	"full_qseq",	// 54
 	"qseq_gapped",  // 55
 	"sseq_gapped",	// 56
-	"qstrand"		// 57
+	"qstrand",		// 57
+	"cigar",		// 58
+	"skingdoms",	// 59
+	"sphylums"		// 60
 };
 
 const char* Blast_tab_format::field_desc[] = {
@@ -126,7 +129,7 @@ const char* Blast_tab_format::field_desc[] = {
 	"Subject scientific names",	// 35 means unique Subject Scientific Name(s), separated by a ';'
 	"scomnames",	// 36 means unique Subject Common Name(s), separated by a ';'
 	"sblastnames",	// 37 means unique Subject Blast Name(s), separated by a ';'	(in alphabetical order)
-	"sskingdoms",	// 38 means unique Subject Super Kingdom(s), separated by a ';'	(in alphabetical order)
+	"Subject super kingdoms",	// 38 means unique Subject Super Kingdom(s), separated by a ';'	(in alphabetical order)
 	"Subject title",		// 39 means Subject Title
 	"Subject titles",	// 40 means All Subject Title(s), separated by a '<>'
 	"sstrand",		// 41 means Subject Strand
@@ -145,7 +148,10 @@ const char* Blast_tab_format::field_desc[] = {
 	"Query sequence",		// 54
 	"Query sequence with gaps",		// 55
 	"Subject sequence with gaps",		// 56
-	"Query strand"						// 57
+	"Query strand",						// 57
+	"CIGAR",								// 58
+	"Subject kingdoms",		// 59
+	"Subject phylums"		// 60
 };
 
 Blast_tab_format::Blast_tab_format() :
@@ -163,10 +169,14 @@ Blast_tab_format::Blast_tab_format() :
 			throw std::runtime_error(string("Invalid output field: ") + *i);
 		if (j == 34)
 			needs_taxon_id_lists = true;
-		if (j == 35) {
+		if (j == 35 || j == 38 || j == 59 || j == 60) {
 			needs_taxon_scientific_names = true;
 			needs_taxon_id_lists = true;
 		}
+		if (j == 38 || j == 59 || j == 60) {
+			needs_taxon_nodes = true;
+			needs_taxon_ranks = true;
+		}
 		fields.push_back(j);
 		if (j == 6 || j == 39 || j == 40 || j == 34)
 			config.salltitles = true;
@@ -182,6 +192,23 @@ void print_staxids(TextBuffer &out, unsigned subject_global_id, const Metadata &
 	out.print((*metadata.taxon_list)[subject_global_id], ';');
 }
 
+template<typename _it>
+void print_taxon_names(_it begin, _it end, const Metadata &metadata, TextBuffer &out) {
+	if (begin == end) {
+		out << "N/A";
+		return;
+	}
+	const vector<string> &names = *metadata.taxonomy_scientific_names;
+	for (_it i = begin; i != end; ++i) {
+		if (i != begin)
+			out << ';';
+		if (*i < names.size() && !names[*i].empty())
+			out << names[*i];
+		else
+			out << *i;
+	}
+}
+
 void Blast_tab_format::print_match(const Hsp_context& r, const Metadata &metadata, TextBuffer &out)
 {
 	for (vector<unsigned>::const_iterator i = fields.begin(); i != fields.end(); ++i) {
@@ -303,16 +330,13 @@ void Blast_tab_format::print_match(const Hsp_context& r, const Metadata &metadat
 			print_staxids(out, r.orig_subject_id, metadata);
 			break;
 		case 35: {
-			const vector<string> &names = *metadata.taxonomy_scientific_names;
 			const vector<unsigned> tax_id = (*metadata.taxon_list)[r.orig_subject_id];
-			for (size_t i = 0; i < tax_id.size(); ++i) {
-				if (i > 0)
-					out << ';';
-				if (tax_id[i] < names.size() && !names[tax_id[i]].empty())
-					out << names[tax_id[i]];
-				else
-					out << tax_id[i];
-			}
+			print_taxon_names(tax_id.begin(), tax_id.end(), metadata, out);
+			break;
+		}
+		case 38: {
+			const set<unsigned> tax_id = metadata.taxon_nodes->rank_taxid((*metadata.taxon_list)[r.orig_subject_id], Rank::superkingdom);
+			print_taxon_names(tax_id.begin(), tax_id.end(), metadata, out);
 			break;
 		}
 		case 39:
@@ -368,6 +392,19 @@ void Blast_tab_format::print_match(const Hsp_context& r, const Metadata &metadat
 			else
 				out << '+';
 			break;
+		case 58:
+			print_cigar(r, out);
+			break;
+		case 59: {
+			const set<unsigned> tax_id = metadata.taxon_nodes->rank_taxid((*metadata.taxon_list)[r.orig_subject_id], Rank::kingdom);
+			print_taxon_names(tax_id.begin(), tax_id.end(), metadata, out);
+			break;
+		}
+		case 60: {
+			const set<unsigned> tax_id = metadata.taxon_nodes->rank_taxid((*metadata.taxon_list)[r.orig_subject_id], Rank::phylum);
+			print_taxon_names(tax_id.begin(), tax_id.end(), metadata, out);
+			break;
+		}
 		default:
 			throw std::runtime_error(string("Invalid output field: ") + field_str[*i]);
 		}
@@ -394,6 +431,7 @@ void Blast_tab_format::print_query_intro(size_t query_num, const char *query_nam
 			case 18:
 			case 33:
 			case 35:
+			case 38:
 			case 39:
 			case 40:
 			case 48:
@@ -401,6 +439,8 @@ void Blast_tab_format::print_query_intro(size_t query_num, const char *query_nam
 			case 55:
 			case 56:
 			case 57:
+			case 59:
+			case 60:
 				out << '*';
 				break;
 			case 12:
