@@ -16,12 +16,16 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
+#include <chrono>
 #include "output.h"
 #include "../data/queries.h"
 
-using namespace std;
+using std::chrono::high_resolution_clock;
+using std::chrono::seconds;
+using std::chrono::milliseconds;
+using std::chrono::duration_cast;
 
-unique_ptr<OutputSink> OutputSink::instance;
+std::unique_ptr<OutputSink> OutputSink::instance;
 
 void OutputSink::push(size_t n, TextBuffer *buf)
 {
@@ -42,7 +46,7 @@ void OutputSink::flush(TextBuffer *buf)
 	size_t n = next_ + 1;
 	vector<TextBuffer*> out;
 	out.push_back(buf);
-	map<size_t, TextBuffer*>::iterator i;
+	std::map<size_t, TextBuffer*>::iterator i;
 	do {
 		while ((i = backlog_.begin()) != backlog_.end() && i->first == n) {
 			out.push_back(i->second);
@@ -70,16 +74,22 @@ void OutputSink::flush(TextBuffer *buf)
 void heartbeat_worker(size_t qend)
 {
 	static const int interval = 100;
+	static thread_local high_resolution_clock::time_point t0 = high_resolution_clock::now();
 	int n = 0;
-	while (OutputSink::get().next() < qend) {
+	size_t next;
+	while ((next = OutputSink::get().next()) < qend) {
 		if (n == interval) {
-			const string title(query_ids::get()[OutputSink::get().next()].c_str());
-			verbose_stream << "Queries=" << OutputSink::get().next() << " size=" << megabytes(OutputSink::get().size()) << " max_size=" << megabytes(OutputSink::get().max_size())
-				<< " next=" << title.substr(0, title.find(' ')) << endl;
+			const string title(query_ids::get()[next].c_str());
+			verbose_stream << "Queries=" << next
+				<< " size=" << megabytes(OutputSink::get().size())
+				<< " max_size=" << megabytes(OutputSink::get().max_size())
+				<< " next=" << title.substr(0, title.find(' '))
+				<< " ETA=" << (double)duration_cast<seconds>(high_resolution_clock::now() - t0).count() / (next - OutputSink::get().begin()) * (qend - next) << "s"
+				<< endl;
 			n = 0;
 		}
 		else
 			++n;
-		std::this_thread::sleep_for(chrono::milliseconds(10));
+		std::this_thread::sleep_for(milliseconds(10));
 	}
 }
\ No newline at end of file
