@@ -43,7 +43,6 @@ using namespace std;
 namespace Workflow { namespace Search {
 
 void run_ref_chunk(DatabaseFile &db_file,
-	Timer &total_timer,
 	unsigned query_chunk,
 	pair<size_t, size_t> query_len_bounds,
 	char *query_buffer,
@@ -53,7 +52,7 @@ void run_ref_chunk(DatabaseFile &db_file,
 	const Metadata &metadata,
 	const vector<unsigned> &block_to_database_id)
 {
-	log_stream << "Current RSS: " << getCurrentRSS() << ", Peak RSS: " << getPeakRSS() << endl;
+	log_rss();
 
 	task_timer timer;
 	if (config.masking == 1) {
@@ -113,7 +112,6 @@ void run_ref_chunk(DatabaseFile &db_file,
 }
 
 void run_query_chunk(DatabaseFile &db_file,
-	Timer &total_timer,
 	unsigned query_chunk,
 	Consumer &master_out,
 	OutputFile *unaligned_file,
@@ -178,14 +176,14 @@ void run_query_chunk(DatabaseFile &db_file,
 		&ref_ids::data_,
 		true,
 		options.db_filter ? options.db_filter : metadata.taxon_filter); ++current_ref_block)
-		run_ref_chunk(db_file, total_timer, query_chunk, query_len_bounds, query_buffer, master_out, tmp_file, params, metadata, block_to_database_id);
+		run_ref_chunk(db_file, query_chunk, query_len_bounds, query_buffer, master_out, tmp_file, params, metadata, block_to_database_id);
 
 	timer.go("Deallocating buffers");
 	delete[] query_buffer;
 	delete query_seeds;
 	query_seeds = 0;
 
-	log_stream << "Current RSS: " << getCurrentRSS() << ", Peak RSS: " << getPeakRSS() << endl;
+	log_rss();
 
 	if (blocked_processing) {
 		timer.go("Joining output blocks");
@@ -210,15 +208,15 @@ void run_query_chunk(DatabaseFile &db_file,
 		ReferenceDictionary::get().clear();
 }
 
-void master_thread(DatabaseFile *db_file, Timer &total_timer, Metadata &metadata, const Options &options)
+void master_thread(DatabaseFile *db_file, task_timer &total_timer, Metadata &metadata, const Options &options)
 {
 	task_timer timer("Opening the input file", true);
-	unique_ptr<TextInputFile> query_file;
+	TextInputFile *query_file = nullptr;
 	const Sequence_file_format *format_n = nullptr;
 	if (!options.self) {
-		if (config.query_file.empty())
+		if (config.query_file.empty() && !options.query_file)
 			std::cerr << "Query file parameter (--query/-q) is missing. Input will be read from stdin." << endl;
-		query_file.reset(new TextInputFile(config.query_file));
+		query_file = options.query_file ? options.query_file : new TextInputFile(config.query_file);
 		format_n = guess_format(*query_file);
 	}
 
@@ -270,12 +268,13 @@ void master_thread(DatabaseFile *db_file, Timer &total_timer, Metadata &metadata
 			timer.finish();
 		}
 
-		run_query_chunk(*db_file, total_timer, current_query_chunk, *master_out, unaligned_file.get(), aligned_file.get(), metadata, options);
+		run_query_chunk(*db_file, current_query_chunk, *master_out, unaligned_file.get(), aligned_file.get(), metadata, options);
 	}
 
-	if (query_file) {
+	if (query_file && !options.query_file) {
 		timer.go("Closing the input file");
 		query_file->close();
+		delete query_file;
 	}
 
 	timer.go("Closing the output file");
@@ -300,15 +299,14 @@ void master_thread(DatabaseFile *db_file, Timer &total_timer, Metadata &metadata
 	metadata.free();
 
 	timer.finish();
-	log_stream << "Current RSS: " << getCurrentRSS() << ", Peak RSS: " << getPeakRSS() << endl;
-	message_stream << "Total time = " << total_timer.getElapsedTimeInSec() << "s" << endl;
+	log_rss();
+	message_stream << "Total time = " << total_timer.get() << "s" << endl;
 	statistics.print();
 }
 
 void run(const Options &options)
 {
-	Timer timer2;
-	timer2.start();
+	task_timer total;
 
 	align_mode = Align_mode(Align_mode::from_command(config.command));
 
@@ -329,29 +327,44 @@ void run(const Options &options)
 
 	init_output(db_file->has_taxon_id_lists(), db_file->has_taxon_nodes(), db_file->has_taxon_scientific_names());
 
-	verbose_stream << "Reference = " << config.database << endl;
-	verbose_stream << "Sequences = " << db_file->ref_header.sequences << endl;
-	verbose_stream << "Letters = " << db_file->ref_header.letters << endl;
-	verbose_stream << "Block size = " << (size_t)(config.chunk_size * 1e9) << endl;
+	message_stream << "Reference = " << config.database << endl;
+	message_stream << "Sequences = " << db_file->ref_header.sequences << endl;
+	message_stream << "Letters = " << db_file->ref_header.letters << endl;
+	message_stream << "Block size = " << (size_t)(config.chunk_size * 1e9) << endl;
 	Config::set_option(config.db_size, (uint64_t)db_file->ref_header.letters);
 	score_matrix.set_db_letters(db_file->ref_header.letters);
 
-	set_max_open_files(config.query_bins * config.threads_ + unsigned(db_file->ref_header.letters / (size_t)(config.chunk_size * 1e9)) + 16);
-
 	Metadata metadata;
 	const bool taxon_filter = !config.taxonlist.empty() || !config.taxon_exclude.empty();
-	if (output_format->needs_taxon_id_lists || taxon_filter) {
-		if (taxon_filter && db_file->header2.taxon_array_offset == 0)
-			throw std::runtime_error("--taxonlist/--taxon-exclude options require taxonomy mapping built into the database.");
+	const bool taxon_culling = config.taxon_k != 0;
+	if (output_format->needs_taxon_id_lists || taxon_filter || taxon_culling) {
+		if (db_file->header2.taxon_array_offset == 0) {
+			if (taxon_filter)
+				throw std::runtime_error("--taxonlist/--taxon-exclude options require taxonomy mapping built into the database.");
+			if (taxon_culling)
+				throw std::runtime_error("--taxon-k option requires taxonomy mapping built into the database.");
+		}
 		timer.go("Loading taxonomy mapping");
 		metadata.taxon_list = new TaxonList(db_file->seek(db_file->header2.taxon_array_offset), db_file->ref_header.sequences, db_file->header2.taxon_array_size);
 		timer.finish();
 	}
-	if (output_format->needs_taxon_nodes || taxon_filter) {
-		if (taxon_filter && db_file->header2.taxon_nodes_offset == 0)
-			throw std::runtime_error("--taxonlist/--taxon-exclude options require taxonomy nodes built into the database.");
+	if (output_format->needs_taxon_nodes || taxon_filter || taxon_culling) {
+		if (db_file->header2.taxon_nodes_offset == 0) {
+			if (taxon_filter)
+				throw std::runtime_error("--taxonlist/--taxon-exclude options require taxonomy nodes built into the database.");
+			if (taxon_culling)
+				throw std::runtime_error("--taxon-k option require taxonomy nodes built into the database.");
+			if(output_format->needs_taxon_nodes)
+				throw std::runtime_error("Output format requires taxonomy nodes built into the database.");
+		}
+		if (db_file->ref_header.build < 131) {
+			if (taxon_culling)
+				throw std::runtime_error("--taxon-k option requires a database built with diamond version >= 0.9.30");
+			if (output_format->needs_taxon_ranks)
+				throw std::runtime_error("Output fields sskingdoms, skingdoms and sphylums require a database built with diamond version >= 0.9.30");
+		}
 		timer.go("Loading taxonomy nodes");
-		metadata.taxon_nodes = new TaxonomyNodes(db_file->seek(db_file->header2.taxon_nodes_offset));
+		metadata.taxon_nodes = new TaxonomyNodes(db_file->seek(db_file->header2.taxon_nodes_offset), db_file->ref_header.build);
 		if (taxon_filter) {
 			timer.go("Building taxonomy filter");
 			metadata.taxon_filter = new TaxonomyFilter(config.taxonlist, config.taxon_exclude, *metadata.taxon_list, *metadata.taxon_nodes);
@@ -366,7 +379,7 @@ void run(const Options &options)
 		timer.finish();
 	}
 
-	master_thread(db_file, timer2, metadata, options);
+	master_thread(db_file, total, metadata, options);
 }
 
 }}
\ No newline at end of file
