@@ -49,9 +49,18 @@ void protein_snps();
 void translate();
 void filter_blasttab();
 void show_cbs();
-void simulate_seqs();
+void reverse();
+void get_medoids_from_tree();
+void roc();
+
 void split();
 namespace Benchmark { DECL_DISPATCH(void, benchmark, ()) }
+namespace Util { namespace Algo { namespace UPGMA { void upgma(); } } }
+namespace Util { namespace Algo { namespace UPGMA_MC { void upgma(); } } }
+namespace Test { void run();
+void simulate_seqs();
+void mutate();
+}
 
 int main(int ac, const char* av[])
 {
@@ -123,7 +132,7 @@ int main(int ac, const char* av[])
 			show_cbs();
 			break;
 		case Config::simulate_seqs:
-			simulate_seqs();
+			Test::simulate_seqs();
 			break;
 		case Config::benchmark:
 			Benchmark::benchmark();
@@ -131,6 +140,27 @@ int main(int ac, const char* av[])
 		case Config::split:
 			split();
 			break;
+		case Config::upgma:
+			Util::Algo::UPGMA::upgma();
+			break;
+		case Config::upgma_mc:
+			Util::Algo::UPGMA_MC::upgma();
+			break;
+		case Config::regression_test:
+			Test::run();
+			break;
+		case Config::reverse_seqs:
+			reverse();
+			break;
+		case Config::compute_medoids:
+			get_medoids_from_tree();
+			break;
+		case Config::mutate:
+			Test::mutate();
+			break;
+		case Config::roc:
+			roc();
+			break;
 #ifdef EXTRA
 		case Config::compare:
 			compare();
@@ -138,9 +168,6 @@ int main(int ac, const char* av[])
 		case Config::model_sim:
 			model_sim();
 			break;
-		case Config::roc:
-			roc();
-			break;
 		case Config::test_extra:
 			test_main();
 			break;
