@@ -23,6 +23,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <iostream>
 #include <sstream>
 #include <memory>
+#include <chrono>
 #include "tools.h"
 #include "../basic/config.h"
 #include "../data/sequence_set.h"
@@ -35,6 +36,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "../basic/packed_transcript.h"
 
 using namespace std;
+using std::chrono::high_resolution_clock;
+using std::chrono::duration_cast;
 
 void get_seq()
 {
@@ -117,6 +120,9 @@ void run_masker()
 	vector<char> id;
 	const FASTA_format format;
 	size_t letters = 0, seqs = 0, seqs_total = 0;
+
+	high_resolution_clock::time_point t1 = high_resolution_clock::now();
+
 	while (format.get_seq(id, seq, f)) {
 		cout << '>' << string(id.data(), id.size()) << endl;
 		seq2 = seq;
@@ -138,8 +144,8 @@ void run_masker()
 		if (n > 0)
 			++seqs;
 		++seqs_total;
-		cerr << "#Sequences: " << seqs << "/" << seqs_total << ", #Letters: " << letters << endl;
 	}
+	cerr << "#Sequences: " << seqs << "/" << seqs_total << ", #Letters: " << letters << ", t=" << (double)duration_cast<std::chrono::milliseconds>(high_resolution_clock::now() - t1).count()/1000.0 << endl;
 }
 
 void fastq2fasta()
@@ -160,8 +166,8 @@ void fastq2fasta()
 void test_io()
 {
 	const size_t buf_size = 1;
-	Timer t;
-	t.start();
+	//Timer t;
+	//t.start();
 	/*InputFile f(config.query_file, InputFile::BUFFERED);
 	char buf[buf_size];	
 	size_t total = 0;
@@ -173,8 +179,8 @@ void test_io()
 	db.load_seqs(v, std::numeric_limits<size_t>::max(), &ref_seqs::data_, &ref_ids::data_);
 
 	size_t total = ref_seqs::get().raw_len() + ref_ids::get().raw_len();
-	cout << "MBytes/sec = " << total / 1e6 / t.getElapsedTime() << endl;
-	cout << "Time = " << t.getElapsedTime() << "s" << endl;
+	//cout << "MBytes/sec = " << total / 1e6 / t.getElapsedTime() << endl;
+	//cout << "Time = " << t.getElapsedTime() << "s" << endl;
 }
 
 void read_sim()
@@ -376,6 +382,25 @@ void translate() {
 	in.close();
 }
 
+void reverse() {
+	input_value_traits = amino_acid_traits;
+	TextInputFile in(config.query_file);
+	vector<char> id, seq;
+	TextBuffer buf;
+	while (FASTA_format().get_seq(id, seq, in)) {
+		buf << '>';
+		buf << '\\';
+		buf.write_raw(id.data(), id.size());
+		buf << '\n';
+		sequence(seq).print(buf, amino_acid_traits, sequence::Reversed());
+		buf << '\n';
+		buf << '\0';
+		cout << buf.get_begin();
+		buf.clear();
+	}
+	in.close();
+}
+
 void show_cbs() {
 	score_matrix = Score_matrix("BLOSUM62", config.gap_open, config.gap_extend, config.frame_shift, 1);
 	init_cbs();
