@@ -34,23 +34,6 @@ void mcl() {
 	graph.print_stats();
 }
 
-vector<char> generate_random_seq(size_t length)
-{
-	vector<char> seq;
-	seq.reserve(length);
-	for (size_t i = 0; i < length; ++i)
-		seq.push_back(get_distribution<20>(background_freq));
-	return seq;
-}
-
-void simulate_seqs() {
-	const size_t l = 300, n = atoi(config.seq_no[0].c_str());
-	for (size_t i = 0; i < n; ++i) {
-		cout << ">" << i << endl;
-		cout << sequence(generate_random_seq(l)) << endl;
-	}
-}
-
 void split() {
 	TextInputFile in(config.query_file);
 	vector<char> id, seq;
