@@ -1,6 +1,6 @@
 /****
 DIAMOND protein aligner
-Copyright (C) 2013-2018 Benjamin Buchfink <buchfink@gmail.com>
+Copyright (C) 2013-2019 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -21,12 +21,13 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <stdlib.h>
 #include <cstdlib>
+#include <utility>
+#include <algorithm>
 #include "../../basic/config.h"
 #include "../util.h"
 #include "radix_cluster.h"
 #include "../data_structures/hash_table.h"
-#include "../memory/memory_pool.h"
-#include "join_result.h"
+#include "../data_structures/double_array.h"
 
 struct RelPtr
 {
@@ -44,12 +45,16 @@ struct RelPtr
 };
 
 template<typename _t>
-void hash_table_join(const Relation<_t> &R, const Relation<_t> &S, unsigned shift, JoinResult<_t> &out)
+void hash_table_join(
+	const Relation<_t> &R,
+	const Relation<_t> &S,
+	unsigned shift,
+	DoubleArray<typename _t::Value> &dst_r,
+	DoubleArray<typename _t::Value> &dst_s)
 {
 	typedef HashTable<unsigned, RelPtr, ExtractBits> Table;
-
+	
 	uint32_t N = (uint32_t)next_power_of_2(R.n * config.join_ht_factor);
-
 	Table table(N, ExtractBits(N, shift));
 	typename Table::Entry *p;
 
@@ -59,7 +64,6 @@ void hash_table_join(const Relation<_t> &R, const Relation<_t> &S, unsigned shif
 		i->key = unsigned(p - table.data());
 	}
 
-	unsigned keys_hit = 0;
 	_t *hit_s = S.data;
 	for (_t *i = S.data; i < S.end(); ++i) {
 		if ((p = table.find_entry(i->key))) {
@@ -67,48 +71,49 @@ void hash_table_join(const Relation<_t> &R, const Relation<_t> &S, unsigned shif
 			hit_s->value = i->value;
 			hit_s->key = unsigned(p - table.data());
 			++hit_s;
-			if (p->s == 1)
-				++keys_hit;
 		}
 	}
 
-	unsigned sum_r = 0, sum_s = 1;
-	DoubleArray<typename _t::Value> *hits_r = new DoubleArray<typename _t::Value>(keys_hit), *hits_s = new DoubleArray<typename _t::Value>(keys_hit);
-	unsigned *limits_r = hits_r->limits(), *limits_s = hits_s->limits();
+	typename DoubleArray<typename _t::Value>::Iterator it_r = dst_r.begin(), it_s = dst_s.begin();
 	
 	for (unsigned i = 0; i < table.size(); ++i) {
 		p = &table.data()[i];
 		if (p->s) {
 			unsigned r = p->r, s = p->s;
-			p->r = sum_r;
-			p->s = sum_s;
-			*(limits_r++) = r;
-			*(limits_s++) = s;
-			sum_r += r;
-			sum_s += s;
+			it_r.count() = r;
+			it_s.count() = s;
+			p->r = dst_r.offset(it_r) + 4;
+			p->s = dst_s.offset(it_s) + 4;
+			it_r.next();
+			it_s.next();
 		}
 	}
-
-	hits_r->init(sum_r);
-	hits_s->init(sum_s - 1);
-	typename _t::Value *data_r = hits_r->data(), *data_s = hits_s->data();
+	dst_r.set_end(it_r);
+	dst_s.set_end(it_s);
 
 	for (const _t *i = R.data; i < R.end(); ++i) {
 		p = &table.data()[i->key];
-		if (p->s)
-			data_r[p->r++] = i->value;
+		if (p->s) {
+			dst_r[p->r] = i->value;
+			p->r += sizeof(typename _t::Value);
+		}
 	}
 
 	for (const _t *i = S.data; i < hit_s; ++i) {
 		p = &table.data()[i->key];
-		data_s[p->s++ - 1] = i->value;
+		dst_s[p->s] = i->value;
+		p->s += sizeof(typename _t::Value);
 	}
-
-	out.push_back(std::make_pair(hits_r, hits_s));
 }
 
 template<typename _t>
-void table_join(const Relation<_t> &R, const Relation<_t> &S, unsigned total_bits, unsigned shift, JoinResult<_t> &out)
+void table_join(
+	const Relation<_t> &R,
+	const Relation<_t> &S,
+	unsigned total_bits,
+	unsigned shift,
+	DoubleArray<typename _t::Value> &dst_r,
+	DoubleArray<typename _t::Value> &dst_s)
 {
 	const unsigned keys = 1 << (total_bits - shift);
 	ExtractBits key(keys, shift);
@@ -118,82 +123,95 @@ void table_join(const Relation<_t> &R, const Relation<_t> &S, unsigned total_bit
 	for (_t *i = R.data; i < R.end(); ++i)
 		++table[key(i->key)].r;
 
-	unsigned keys_hit = 0;
 	_t *hit_s = S.data;
 	for (_t *i = S.data; i < S.end(); ++i) {
 		if ((p = &table[key(i->key)])->r) {
 			++p->s;
-			memcpy(hit_s++, i, sizeof(_t));
-			if (p->s == 1)
-				++keys_hit;
+			std::copy(i, i + 1, hit_s++);
 		}
 	}
 
-	unsigned sum_r = 0, sum_s = 1;
-	DoubleArray<typename _t::Value> *hits_r = new DoubleArray<typename _t::Value>(keys_hit), *hits_s = new DoubleArray<typename _t::Value>(keys_hit);
-	unsigned *limits_r = hits_r->limits(), *limits_s = hits_s->limits();
+	typename DoubleArray<typename _t::Value>::Iterator it_r = dst_r.begin(), it_s = dst_s.begin();
 
 	for (unsigned i = 0; i < keys; ++i) {
 		p = &table[i];
 		if (p->s) {
 			unsigned r = p->r, s = p->s;
-			p->r = sum_r;
-			p->s = sum_s;
-			*(limits_r++) = r;
-			*(limits_s++) = s;
-			sum_r += r;
-			sum_s += s;
+			it_r.count() = r;
+			it_s.count() = s;
+			p->r = dst_r.offset(it_r) + 4;
+			p->s = dst_s.offset(it_s) + 4;
+			it_r.next();
+			it_s.next();
 		}
 	}
+	dst_r.set_end(it_r);
+	dst_s.set_end(it_s);
 
-	hits_r->init(sum_r);
-	hits_s->init(sum_s - 1);
-	typename _t::Value *data_r = hits_r->data(), *data_s = hits_s->data();
-	
 	for (const _t *i = R.data; i < R.end(); ++i) {
 		p = &table[key(i->key)];
-		if (p->s)
-			data_r[p->r++] = i->value;
+		if (p->s) {
+			dst_r[p->r] = i->value;
+			p->r += sizeof(typename _t::Value);
+		}
 	}
 
 	for (const _t *i = S.data; i < hit_s; ++i) {
 		p = &table[key(i->key)];
-		data_s[p->s++ - 1] = i->value;
+		dst_s[p->s] = i->value;
+		p->s += sizeof(typename _t::Value);
 	}
-	
+
 	free(table);
-	out.push_back(std::make_pair(hits_r, hits_s));
 }
 
 template<typename _t>
-void hash_join(const Relation<_t> &R, const Relation<_t> &S, JoinResult<_t> &out, MemoryPool &tmp_pool, unsigned total_bits = 32, unsigned shift = 0)
+void hash_join(
+	Relation<_t> R,
+	Relation<_t> S,
+	_t *dst_r,
+	_t *dst_s,
+	DoubleArray<typename _t::Value> &out_r,
+	DoubleArray<typename _t::Value> &out_s,
+	unsigned total_bits = 32,
+	unsigned shift = 0)
 {
 	if (R.n == 0 || S.n == 0)
 		return;
 	const unsigned key_bits = total_bits - shift;
 	if (R.n < config.join_split_size || key_bits < config.join_split_key_len) {
+		DoubleArray<typename _t::Value> tmp_r((void*)dst_r), tmp_s((void*)dst_s);
 		if (next_power_of_2(R.n * config.join_ht_factor) < 1llu << key_bits)
-			hash_table_join(R, S, shift, out);
+			hash_table_join(R, S, shift, tmp_r, tmp_s);
 		else
-			table_join(R, S, total_bits, shift, out);
+			table_join(R, S, total_bits, shift, tmp_r, tmp_s);
+		out_r.append(tmp_r);
+		out_s.append(tmp_s);
 	}
 	else {
 		const unsigned clusters = 1 << config.radix_bits;
-		_t *outR = tmp_pool.alloc<_t>(R.n), *outS = tmp_pool.alloc<_t>(S.n);
 		unsigned *hstR = new unsigned[clusters], *hstS = new unsigned[clusters];
-		radix_cluster(R, shift, outR, hstR);
-		radix_cluster(S, shift, outS, hstS);
+		radix_cluster(R, shift, dst_r, hstR);
+		radix_cluster(S, shift, dst_s, hstS);
 
 		shift += config.radix_bits;
-		hash_join(Relation<_t>(outR, hstR[0]), Relation<_t>(outS, hstS[0]), out, tmp_pool, total_bits, shift);
+		hash_join(Relation<_t>(dst_r, hstR[0]), Relation<_t>(dst_s, hstS[0]), R.data, S.data, out_r, out_s, total_bits, shift);
 		for (unsigned i = 1; i < clusters; ++i)
-			hash_join(Relation<_t>(&outR[hstR[i - 1]], hstR[i] - hstR[i - 1]), Relation<_t>(&outS[hstS[i - 1]], hstS[i] - hstS[i - 1]), out, tmp_pool, total_bits, shift);
+			hash_join(Relation<_t>(dst_r + hstR[i - 1], hstR[i] - hstR[i - 1]), Relation<_t>(dst_s + hstS[i - 1], hstS[i] - hstS[i - 1]), R.data + hstR[i - 1], S.data + hstS[i - 1], out_r, out_s, total_bits, shift);
 
 		delete[] hstR;
 		delete[] hstS;
-		tmp_pool.free(outR);
-		tmp_pool.free(outS);
 	}
 }
 
+template<typename _t>
+std::pair<DoubleArray<typename _t::Value>, DoubleArray<typename _t::Value>> hash_join(Relation<_t> R, Relation<_t> S, unsigned total_bits = 32) {
+	_t *buf_r = (_t*)malloc(sizeof(_t) * R.n), *buf_s = (_t*)malloc(sizeof(_t) * S.n);
+	DoubleArray<typename _t::Value> out_r((void*)R.data), out_s((void*)S.data);
+	hash_join(R, S, buf_r, buf_s, out_r, out_s, total_bits);
+	free(buf_r);
+	free(buf_s);
+	return { out_r, out_s };
+}
+
 #endif
\ No newline at end of file
