@@ -21,9 +21,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <algorithm>
 #include "radix_cluster.h"
-#include "../memory/memory_pool.h"
 
-template<typename _t>
+/*template<typename _t>
 void radix_sort(Relation<_t> &R, unsigned total_bits, _t *buf = 0)
 {
 	bool dealloc = false;
@@ -42,6 +41,6 @@ void radix_sort(Relation<_t> &R, unsigned total_bits, _t *buf = 0)
 	//if(dealloc) delete[] buf;
 	if (dealloc) MemoryPool::global().free(buf);
 	delete[] hst;
-}
+}*/
 
 #endif
\ No newline at end of file
