@@ -3,16 +3,16 @@ DIAMOND protein aligner
 Copyright (C) 2013-2017 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU Affero General Public License as
-published by the Free Software Foundation, either version 3 of the
-License, or (at your option) any later version.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU Affero General Public License for more details.
+GNU General Public License for more details.
 
-You should have received a copy of the GNU Affero General Public License
+You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
@@ -26,8 +26,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <string.h>
 #include "hash_function.h"
 
-using std::auto_ptr;
-
 struct hash_table_overflow_exception : public std::exception
 {
 	virtual const char* what() const throw()
@@ -44,82 +42,6 @@ bool operator()(T x) const
 }
 };
 
-template<typename _K, typename _V, typename _E, typename _H> class hash_table
-{
-
-public:
-
-	struct entry
-	{
-		_K	key;
-		_V	value;
-	}; // __attribute__((packed));
-
-	hash_table(size_t size) :
-		table(new entry[size]),
-		size_(size)
-	{
-		memset(table, 0, size_ * sizeof(entry));
-	}
-
-	~hash_table()
-	{
-		delete[] table;
-	}
-
-	entry* operator[](_K key) const
-	{
-		entry *entry = get_entry(key);
-		if (_E()(entry->value))
-			return NULL;
-		return entry;
-	}
-
-	void insert(_K key, _V value)
-	{
-		entry *entry = get_entry(key);
-		if (_E()(entry->value))
-			entry->key = key;
-		entry->value = value;
-	}
-
-	size_t size() const
-	{
-		return size_;
-	}
-
-	size_t count() const
-	{
-		size_t n(0);
-		for (size_t i = 0; i < size_; ++i)
-			if (!_E()(table[i].value))
-				++n;
-		return n;
-	}
-
-private:
-
-	entry* get_entry(_K key) const
-	{
-		entry *p = &table[_H()(key) % size_];
-		bool wrapped = false;
-		while (p->key != key && !_E()(p->value)) {
-			++p;
-			if (p == &table[size_]) {
-				if (wrapped)
-					throw hash_table_overflow_exception();
-				p = &table[0];
-				wrapped = true;
-			}
-		}
-		return p;
-	}
-
-	entry	*table;
-	size_t	 size_;
-
-};
-
 template<typename _V> class PHash_table
 {
 
@@ -204,7 +126,7 @@ private:
 	}
 
 	size_t size_;
-	auto_ptr<entry> table;	
+	std::unique_ptr<entry> table;	
 
 };
 
@@ -305,7 +227,7 @@ private:
 		}
 	}
 
-	auto_ptr<fp> table;
+	std::unique_ptr<fp> table;
 	size_t size_;
 
 };
