@@ -3,16 +3,16 @@ DIAMOND protein aligner
 Copyright (C) 2013-2017 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU Affero General Public License as
-published by the Free Software Foundation, either version 3 of the
-License, or (at your option) any later version.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU Affero General Public License for more details.
+GNU General Public License for more details.
 
-You should have received a copy of the GNU Affero General Public License
+You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
@@ -209,12 +209,8 @@ struct TextBuffer
 	TextBuffer& print(unsigned i, unsigned width)
 	{
 		reserve(16);
-		char buf[16];
-		const int n = sprintf(buf, "%u", i),
-			padding = std::max((int)width - n, 0);
-		memset(ptr_, ' ', padding);
-		memcpy(ptr_ + padding, buf, n);
-		ptr_ += padding + n;
+		sprintf(ptr_, "%*u", width, i);
+		ptr_ += width;
 		return *this;
 	}
 
@@ -228,12 +224,6 @@ struct TextBuffer
 		return *this;
 	}
 
-	/*Text_buffer& operator<<(uint8_t x)
-	{
-		write(x);
-		return *this;
-	}*/
-
 	template<typename _t>
 	TextBuffer& operator<<(const vector<_t> &v)
 	{
